djmessenger.management package — djmessenger 1.1.0 documentation

# djmessenger.management package

## Subpackages

- djmessenger.management.commands package
  - Submodules
  - djmessenger.management.commands.configure_get_started_button module
  - djmessenger.management.commands.configure_greetings module
  - djmessenger.management.commands.configure_persistent_menu module
  - djmessenger.management.commands.get_random_endpoint module
  - Module contents

## Module contents